local mod = ...

--[[

Test comparing the two types of vegetable fields:
Group 1 was 3 beet fields of the older type with 1 worker each
Group 2 was a similar sized free-form field with 3 workers

Group A:
Produced 24 veg for 14 days
    started on week 2 day 1
    By Week 4 day 1 the 3 single farms had produced 24 veg

Group B:
Produced 30 veg for 21 days (but they finished 5 days early)
This group could produce probably 3x that amount - so produces roughly the same veg in the same space, but with fewer workers if the farm is large
    sowing started week 4 day 1
    sowing finished week 4 day 2
    growing started week 4 day 7
    harvesting started week 1 day 6
    harvesting complete week 2 day 1
    total harvest was 30 

]]



-- Assets -------------------------------------------------------------------------------------
-- Models used for the plants must have only a single Mesh and a single Material, otherwise planting will crash!
mod:registerAssetId("models/VegetableFarm1.fbx/Prefab/FarmPart", "PREFAB_VEGETABLE_FARM1")
mod:registerAssetId("models/VegetableFarm1.fbx/Prefab/ShedPart", "PREFAB_VEGETABLE_SHED1")
mod:registerAssetId("models/Textures/colors.png", "TEXTURE_COLOR")
mod:registerAssetId("models/VegetableBeet.fbx/Prefab/Plant", "PREFAB_VEGETABLE_BEET")
mod:registerAssetId("models/VegetableCabbage.fbx/Prefab/Plant", "PREFAB_VEGETABLE_CABBAGE")
mod:registerAssetId("models/VegetableBean.fbx/Prefab/Plant", "PREFAB_VEGETABLE_BEAN")
mod:registerAssetId("models/VegetableBroccoli.fbx/Prefab/Plant", "PREFAB_VEGETABLE_BROCCOLI")
mod:registerAssetId("models/Character.fbx/Prefab/HatPart1", "PREFAB_HAT_FARMER1") -- BROWN - FEMALE hat, hair and backpack basket
mod:registerAssetId("models/Character.fbx/Prefab/HatPart2", "PREFAB_HAT_FARMER2") -- BROWN - MALE hat, hair and backpack basket
mod:registerAssetId("models/Character.fbx/Prefab/HatPart3", "PREFAB_HAT_FARMER3") -- BROWN - UNISEX hat, hair



-- Construction visual -------------------------------------------------------------------------------------
mod:registerAssetId("models/VegetableFarm1.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLE_FARM1")



-- Attach Node Type -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/VegetableFarm1.fbx/Prefab/ShedPart", { DataType = "COMP_BUILDING_PART", BuildingPartType = "MINOR" })



-- Grass clearing -------------------------------------------------------------------------------------
-- If strength or size of the grass clearing is too high or big, no plants can be planted the next cycle!

-- mod:registerPrefabComponent("models/VegetableBeet.fbx/Prefab/Plant", {
--     DataType = "COMP_DIRT_CIRCLE", 
--     HardRadius = 0.1,
--     SoftRadius = 0.2, 
--     Strength = 0.4,
--     IsPermanent = false 
-- })

-- mod:registerPrefabComponent("models/VegetableCabbage.fbx/Prefab/Plant", { 
--     DataType = "COMP_DIRT_CIRCLE", 
--     HardRadius = 0.1,
--     SoftRadius = 0.2, 
--     Strength = 0.4,
--     IsPermanent = false 
-- })

-- mod:registerPrefabComponent("models/VegetableBean.fbx/Prefab/Plant", { 
--     DataType = "COMP_DIRT_CIRCLE", 
--     HardRadius = 0.1,
--     SoftRadius = 0.2, 
--     Strength = 0.4,
--     IsPermanent = false 
-- })

-- mod:registerPrefabComponent("models/VegetableBroccoli.fbx/Prefab/Plant", { 
--     DataType = "COMP_DIRT_CIRCLE", 
--     HardRadius = 0.1,
--     SoftRadius = 0.2, 
--     Strength = 0.4,
--     IsPermanent = false 
-- })



-- Crop Field Element -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/VegetableBeet.fbx/Prefab/Plant", { DataType = "COMP_CROP_FIELD_ELEMENT" })
mod:registerPrefabComponent("models/VegetableCabbage.fbx/Prefab/Plant", { DataType = "COMP_CROP_FIELD_ELEMENT" })
mod:registerPrefabComponent("models/VegetableBean.fbx/Prefab/Plant", { DataType = "COMP_CROP_FIELD_ELEMENT" })
mod:registerPrefabComponent("models/VegetableBroccoli.fbx/Prefab/Plant", { DataType = "COMP_CROP_FIELD_ELEMENT" })



-- Plantable -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/VegetableBeet.fbx/Prefab/Plant", { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 1.0 })
mod:registerPrefabComponent("models/VegetableCabbage.fbx/Prefab/Plant", { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 1.0 })
mod:registerPrefabComponent("models/VegetableBean.fbx/Prefab/Plant", { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 1.0 })
mod:registerPrefabComponent("models/VegetableBroccoli.fbx/Prefab/Plant", { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 1.0 })

mod:register({
    DataType = "PLANTABLE",
    Id = "PLANTABLE_VEGETABLE_BEET",
    Name = "PLANTABLE_VEGETABLE_BEET_NAME",
    PlantPrefab = "PREFAB_VEGETABLE_BEET",
    MinimumScale = 0.85, -- min size at full growth
    MaximumScale = 1.15 -- max size at full growth
})

mod:register({
    DataType = "PLANTABLE",
    Id = "PLANTABLE_VEGETABLE_CABBAGE",
    Name = "PLANTABLE_VEGETABLE_CABBAGE_NAME",
    PlantPrefab = "PREFAB_VEGETABLE_CABBAGE",
    MinimumScale = 0.85,
    MaximumScale = 1.15
})

mod:register({
    DataType = "PLANTABLE",
    Id = "PLANTABLE_VEGETABLE_BEAN",
    Name = "PLANTABLE_VEGETABLE_BEAN_NAME",
    PlantPrefab = "PREFAB_VEGETABLE_BEAN",
    MinimumScale = 0.85,
    MaximumScale = 1.15
})

mod:register({
    DataType = "PLANTABLE",
    Id = "PLANTABLE_VEGETABLE_BROCCOLI",
    Name = "PLANTABLE_VEGETABLE_BROCCOLI_NAME",
    PlantPrefab = "PREFAB_VEGETABLE_BROCCOLI",
    MinimumScale = 0.85,
    MaximumScale = 1.15
})



-- Resource -------------------------------------------------------------------------------------

mod:registerAssetId("icons/RawVegetable.png", "ICON_RAW_VEGETABLE")

mod:register({
	DataType = "RESOURCE",
	Id = "RAW_VEGETABLE_RESOURCE",
	ResourceName = "RAW_VEGETABLE_RESOURCE_NAME",
	Icon = "ICON_RAW_VEGETABLE",
	ResourceTypeList = { "RESOURCE" },
	IsTradable = false,
	ResourceLayoutType = "CRATES",
	DisplayInInventory = false
})



-- Resource Container -------------------------------------------------------------------------------------
mod:registerPrefabComponent( "models/VegetableBeet.fbx/Prefab/Plant", {
    DataType = "COMP_RESOURCE_CONTAINER",
    ResourceData = "RAW_VEGETABLE_RESOURCE",
    IsReplenishable = false,
    ResourceValue = 1.0, -- how many are gathered with each pick
    AvailableQuantity = 1, -- maximum container stock
    Radius = 0.85, -- distance from container that the villager will stand to pick
    IsDestroyWhenEmpty = true,
    HasMaximumWorkstation = false
})

mod:registerPrefabComponent( "models/VegetableCabbage.fbx/Prefab/Plant", {
    DataType = "COMP_RESOURCE_CONTAINER",
    ResourceData = "RAW_VEGETABLE_RESOURCE",
    IsReplenishable = false,
    ResourceValue = 1.0, -- how many are gathered with each pick
    AvailableQuantity = 1, -- maximum container stock
    Radius = 0.85, -- distance from container that the villager will stand to pick
    IsDestroyWhenEmpty = true,
    HasMaximumWorkstation = false
})

mod:registerPrefabComponent( "models/VegetableBean.fbx/Prefab/Plant", {
    DataType = "COMP_RESOURCE_CONTAINER",
    ResourceData = "RAW_VEGETABLE_RESOURCE",
    IsReplenishable = false,
    ResourceValue = 1.0, -- how many are gathered with each pick
    AvailableQuantity = 1, -- maximum container stock
    Radius = 0.85, -- distance from container that the villager will stand to pick
    IsDestroyWhenEmpty = true,
    HasMaximumWorkstation = false
})

mod:registerPrefabComponent( "models/VegetableBroccoli.fbx/Prefab/Plant", {
    DataType = "COMP_RESOURCE_CONTAINER",
    ResourceData = "RAW_VEGETABLE_RESOURCE",
    IsReplenishable = false,
    ResourceValue = 1.0, -- how many are gathered with each pick
    AvailableQuantity = 1, -- maximum container stock
    Radius = 0.85, -- distance from container that the villager will stand to pick
    IsDestroyWhenEmpty = true,
    HasMaximumWorkstation = false
})



-- Building Asset Processor  -------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/VegetableFarm1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Collider Platform (climbable mesh)  -------------------------------------------------------------------------------------
mod:configurePrefabFlagList("models/VegetableFarm1.fbx/Prefab/VegetablePatchPart", { "PLATFORM" })



-- Building part type
mod:registerEnumValue("BUILDING_PART_TYPE", "SHED")



-- Zone -------------------------------------------------------------------------------------
mod:register({
    DataType = "ZONE",
    Id = "ZONE_VEGETABLE_FARM",
    Name = "ZONE_VEGETABLE_FARM_NAME",
    Description = "ZONE_VEGETABLE_FARM_DESC",
    Color = {0.40, 1.70, 0.60, 0.9}, -- RGB A = Light green
    DesirabilityLayerToShow = "DESIRABILITY_FERTILITY"
})



-- Material -------------------------------------------------------------------------------------
mod:register({
	DataType = "MATERIAL",
	Id = "MATERIAL_VEGETABLE_COLOR",
	HasAlphaTest = false,
	AlbedoTexture = "TEXTURE_COLOR"
})



-- Farm Field Config -------------------------------------------------------------------------------------
mod:register({
    DataType = "FARM_FIELD_CONFIG",
    Id = "FARM_FIELD_CONFIG_VEGETABLE_FARM_BEET",
    ZoneType = "ZONE_VEGETABLE_FARM",
    PlantPrefab = "PREFAB_VEGETABLE_BEET",
    HasPlantingCycle = true,
    IsScaling = true,
    RowDistance = 1.5,
    ItemDistance = 1.15,
    RandomOrientation = {0, 360},
    RandomPositionOffset = {-.15, 0.15},
    SourceMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingMaterial = "MATERIAL_VEGETABLE_COLOR",
    HarvestedMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingTextureList = {
        "TEXTURE_COLOR",
    },
    HarvestingTextureList = {
        "TEXTURE_COLOR",
    },
    AlphaTestThreshold = 0.5
})

mod:register({
    DataType = "FARM_FIELD_CONFIG",
    Id = "FARM_FIELD_CONFIG_VEGETABLE_FARM_CABBAGE",
    ZoneType = "ZONE_VEGETABLE_FARM",
    PlantPrefab = "PREFAB_VEGETABLE_CABBAGE",
    HasPlantingCycle = true,
    IsScaling = false,
    RowDistance = 1.75,
    ItemDistance = 1.75,
    RandomOrientation = {0, 345},
    RandomPositionOffset = {-.15, 0.15},
    SourceMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingMaterial = "MATERIAL_VEGETABLE_COLOR",
    HarvestedMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingTextureList = {
        "TEXTURE_COLOR",
    },
    HarvestingTextureList = {
        "TEXTURE_COLOR",
    },
    AlphaTestThreshold = 0.5
})

mod:register({
    DataType = "FARM_FIELD_CONFIG",
    Id = "FARM_FIELD_CONFIG_VEGETABLE_FARM_BEAN",
    ZoneType = "ZONE_VEGETABLE_FARM",
    PlantPrefab = "PREFAB_VEGETABLE_BEAN",
    HasPlantingCycle = true,
    IsScaling = true,
    RowDistance = 1.5,
    ItemDistance = 1.15,
    RandomOrientation = {0, 345},
    RandomPositionOffset = {-.1, 0.1},
    SourceMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingMaterial = "MATERIAL_VEGETABLE_COLOR",
    HarvestedMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingTextureList = {
        "TEXTURE_COLOR",
    },
    HarvestingTextureList = {
        "TEXTURE_COLOR",
    },
    AlphaTestThreshold = 0.5
})

mod:register({
    DataType = "FARM_FIELD_CONFIG",
    Id = "FARM_FIELD_CONFIG_VEGETABLE_FARM_BROCCOLI",
    ZoneType = "ZONE_VEGETABLE_FARM",
    PlantPrefab = "PREFAB_VEGETABLE_BROCCOLI",
    HasPlantingCycle = true,
    IsScaling = false,
    RowDistance = 1.75,
    ItemDistance = 1.45,
    RandomOrientation = {0, 345},
    RandomPositionOffset = {-.15, 0.15},
    SourceMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingMaterial = "MATERIAL_VEGETABLE_COLOR",
    HarvestedMaterial = "MATERIAL_VEGETABLE_COLOR",
    GrowingTextureList = {
        "TEXTURE_COLOR",
    },
    HarvestingTextureList = {
        "TEXTURE_COLOR",
    },
    AlphaTestThreshold = 0.5
})



-- Sowing Setup -------------------------------------------------------------------------------------

mod:register({
    DataType = "AGENT_WORKSTATION_SETUP",
    Id = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_SOWING",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        LeftHandObject = {
            Model = "PREFAB_TOOL_FARMER_SEED_BAG", 
            WorkAttachName = "SeedBag_Anchor", 
            WalkAttachName = "SeedBag_Anchor"
        },
        FemaleHatList = {
            "PREFAB_HAT_FARMER3",
        }, 
        MaleHatList = {
            "PREFAB_HAT_FARMER3",
        }, 
        WalkAnimation = "WALKING",
        IdleAnimation = "FORESTER"
	}
})



-- Harvest Setup: Orchard Farm -------------------------------------------------------------------------------------

mod:register({
    DataType = "AGENT_WORKSTATION_SETUP",
    Id = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_HARVEST",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        FemaleHatList = {
            "PREFAB_HAT_FARMER1",
        }, 
        MaleHatList = {
            "PREFAB_HAT_FARMER2",
        }, 
        WalkAnimation = "WALKING",
		IdleAnimation = "GATHER"
	}
})



-- Job: Vegetable Farmer (field worker) -------------------------------------------------------------------------------------

mod:register({
	DataType = "JOB",
	Id = "VEGETABLEFARMER2_JOB",
	JobName = "VEGETABLEFARMER_JOB_NAME",
	JobDescription = "VEGETABLEFARMER_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_FARMER",
    ProductionDelay = 2.0, -- time to spend pulling the plant out of the ground
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        FemaleHatList = {
            "PREFAB_HAT_FARMER3",
        }, 
        MaleHatList = {
            "PREFAB_HAT_FARMER3",
        }, 
		IdleAnimation = "FORESTER"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "VEGETABLEFARMER2_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "VEGETABLEFARMER2_JOB"
    }
})



-- Job: Vegetable Farmer (shed worker / food processor) -------------------------------------------------------------------------------------

mod:register({
	DataType = "JOB",
	Id = "VEGETABLEFARMER3_JOB",
	JobName = "VEGETABLEFARMER_JOB_NAME",
	JobDescription = "VEGETABLEFARMER_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 20.0,
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        FemaleHatList = {
            "PREFAB_HAT_FARMER3",
        }, 
        MaleHatList = {
            "PREFAB_HAT_FARMER3",
        }, 
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "VEGETABLEFARMER3_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "VEGETABLEFARMER3_JOB"
    }
})



-- Building Function Assignable  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_ASSIGNABLE",
    Id = "BUILDING_FUNCTION_ASSIGNABLE_VEGETABLE_FARM",
	Name = "BUILDING_FUNCTION_ASSIGNABLE_VEGETABLE_FARM_NAME",
	AuthorizedFunctionList = "BUILDING_FUNCTION_LIST_VEGETABLE_FARM"
})



-- Building Function List  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_LIST",
    Id = "BUILDING_FUNCTION_LIST_VEGETABLE_FARM",
	AssetFunctionList = {
		"BUILDING_FUNCTION_VEGETABLE_FARM_BEET",
		"BUILDING_FUNCTION_VEGETABLE_FARM_CABBAGE",
		"BUILDING_FUNCTION_VEGETABLE_FARM_BEAN",
		"BUILDING_FUNCTION_VEGETABLE_FARM_BROCCOLI",
	}
})



-- Building Function: Beets -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_FARM",
    Id = "BUILDING_FUNCTION_VEGETABLE_FARM_BEET",
    Name = "BUILDING_FUNCTION_VEGETABLE_FARM_BEET_NAME",
    WorkerCapacity = 3,
    RelatedJob = { 
        Job = "VEGETABLEFARMER2_JOB", 
        Behavior = "BEHAVIOR_FARMER"
    },
    -- InputInventoryCapacity = {
	-- 	{ Resource = "WATER", Quantity = 5 },
	-- 	-- { Resource = "DUNG_RESOURCE", Quantity = 5 }
	-- },
    ResourceListNeeded = {
		{ Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 }, 
	},
	ResourceProduced = {
        { Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 },
    },

    -- there is a max total cycle of 21 days so if you plan beyond that, it will be cut short
    SowingDurationPerc = {0, 6},
	GrowDuration = {6, 10},
	GrowWaitDuration = {10, 12},
	HarvestDuration = {12, 18},
	RestDuration = {18, 21},

    QuantityToHarvestPerStep = 1,
	HarvestStepsCount = 10,
	QuantityToPlantPerStep = 1,
	PlantingStepsCount = 1,
	ResourceValuePerGather = 0.15,

    CropFieldConfig = "FARM_FIELD_CONFIG_VEGETABLE_FARM_BEET",
    SowingSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_SOWING", 
    HarvestSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_HARVEST"
})



-- Building Function: Cabbage -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_FARM",
    Id = "BUILDING_FUNCTION_VEGETABLE_FARM_CABBAGE",
    Name = "BUILDING_FUNCTION_VEGETABLE_FARM_CABBAGE_NAME",
    WorkerCapacity = 3,
    RelatedJob = { 
        Job = "VEGETABLEFARMER2_JOB", 
        Behavior = "BEHAVIOR_FARMER"
    },
    -- InputInventoryCapacity = {
	-- 	{ Resource = "WATER", Quantity = 5 },
	-- 	{ Resource = "DUNG_RESOURCE", Quantity = 5 }
	-- },
    ResourceListNeeded = {
		{ Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 }, 
	},
	ResourceProduced = {
        { Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 },
    },

    -- there is a max total cycle of 21 days so if you plan beyond that, it will be cut short
    SowingDurationPerc = {0, 6},
	GrowDuration = {6, 10},
	GrowWaitDuration = {10, 12},
	HarvestDuration = {12, 18},
	RestDuration = {18, 21},

    QuantityToHarvestPerStep = 1,
	HarvestStepsCount = 5,
	QuantityToPlantPerStep = 1,
	PlantingStepsCount = 1,
	ResourceValuePerGather = 0.25,

    CropFieldConfig = "FARM_FIELD_CONFIG_VEGETABLE_FARM_CABBAGE",
    SowingSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_SOWING", 
    HarvestSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_HARVEST"
})



-- Building Function: Beans -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_FARM",
    Id = "BUILDING_FUNCTION_VEGETABLE_FARM_BEAN",
    Name = "BUILDING_FUNCTION_VEGETABLE_FARM_BEAN_NAME",
    WorkerCapacity = 3,
    RelatedJob = { 
        Job = "VEGETABLEFARMER2_JOB", 
        Behavior = "BEHAVIOR_FARMER"
    },
    -- InputInventoryCapacity = {
	-- 	{ Resource = "WATER", Quantity = 5 },
	-- 	{ Resource = "DUNG_RESOURCE", Quantity = 5 }
	-- },
    ResourceListNeeded = {
		{ Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 }, 
	},
	ResourceProduced = {
        { Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 },
    },

    -- there is a max total cycle of 21 days so if you plan beyond that, it will be cut short
    SowingDurationPerc = {0, 6},
	GrowDuration = {6, 10},
	GrowWaitDuration = {10, 12},
	HarvestDuration = {12, 18},
	RestDuration = {18, 21},

    QuantityToHarvestPerStep = 1,
	HarvestStepsCount = 20,
	QuantityToPlantPerStep = 1,
	PlantingStepsCount = 1,
	ResourceValuePerGather = 0.25,

    CropFieldConfig = "FARM_FIELD_CONFIG_VEGETABLE_FARM_BEAN",
    SowingSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_SOWING", 
    HarvestSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_HARVEST"
})



-- Building Function: Broccoli -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_FARM",
    Id = "BUILDING_FUNCTION_VEGETABLE_FARM_BROCCOLI",
    Name = "BUILDING_FUNCTION_VEGETABLE_FARM_BROCCOLI_NAME",
    WorkerCapacity = 3,
    RelatedJob = { 
        Job = "VEGETABLEFARMER2_JOB", 
        Behavior = "BEHAVIOR_FARMER"
    },
    -- InputInventoryCapacity = {
	-- 	{ Resource = "WATER", Quantity = 5 },
	-- 	{ Resource = "DUNG_RESOURCE", Quantity = 5 }
	-- },
    ResourceListNeeded = {
		{ Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 }, 
	},
	ResourceProduced = {
        { Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 1 },
    },

    -- there is a max total cycle of 21 days so if you plan beyond that, it will be cut short
    SowingDurationPerc = {0, 6},
	GrowDuration = {6, 10},
	GrowWaitDuration = {10, 12},
	HarvestDuration = {12, 18},
	RestDuration = {18, 21},

    QuantityToHarvestPerStep = 1,
	HarvestStepsCount = 5,
	QuantityToPlantPerStep = 1,
	PlantingStepsCount = 1,
	ResourceValuePerGather = 0.25,

    CropFieldConfig = "FARM_FIELD_CONFIG_VEGETABLE_FARM_BROCCOLI",
    SowingSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_SOWING", 
    HarvestSetup = "AGENT_WORKSTATION_SETUP_VEGETABLE_FARM_HARVEST"
})



-- Building Function: Vegetable shed -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "VEGETABLESHED_FUNCTION",
    Name = "VEGETABLESHED_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "VEGETABLEFARMER3_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 20 },
		{ Resource = "COMPOST_RESOURCE", Quantity = 20 },
		{ Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 20 },
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 },
		{ Resource = "COMPOST_RESOURCE", Quantity = 1 },
		{ Resource = "RAW_VEGETABLE_RESOURCE", Quantity = 5 },
	},
	ResourceProduced = {{ Resource = "VEGETABLE_RESOURCE", Quantity = 5 }}

})



-- Building part: Vegetable Farm 1 (storage and work building) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
    Id = "BUILDING_PART_VEGETABLE_FARM1",
    Name = "BUILDING_PART_VEGETABLE_FARM1_NAME",
    Category = "CORE", 
    AssetBuildingFunction = "BUILDING_FUNCTION_ASSIGNABLE_VEGETABLE_FARM",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {5.25, 5.25}, {0.0, 0.0}),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
            },
		}
	},
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_VEGETABLE_FARM1"
    }, 
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLE_FARM1",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 5 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 5 } },
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 10 },
            { Resource = "STONE", Quantity = 5 },
            { Resource = "PLANK", Quantity = 5 },
		}
    }
})



-- Building part: Vegetable Shed 1 (water, compost collection and vegetable processing) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
    Id = "BUILDING_PART_VEGETABLE_SHED1",
    Name = "BUILDING_PART_VEGETABLE_SHED1_NAME",
    Category = "SHED", 
    AssetBuildingFunction = "VEGETABLESHED_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {5.25, 2.5}, {0.0, 0.0}),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
            },
		}
	},
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_VEGETABLE_SHED1"
    }, 
	Cost = {
		-- BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 5 } },
		-- UpkeepCost = { { Resource = "GOLD", Quantity = 5 } },
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 1 },
            { Resource = "PLANK", Quantity = 2 },
		}
    }
})
